tietools.tie_chain_to_augmented_tuplet_with_proportions_and_encourage_dots
==========================================================================

.. autofunction:: abjad.tools.tietools.tie_chain_to_augmented_tuplet_with_proportions_and_encourage_dots.tie_chain_to_augmented_tuplet_with_proportions_and_encourage_dots
